
========
工程说明
========

DNSPod 提供域名一站式服务，包括域名注册、DNS 管理、SSL 证书、网站备案等，您都可以在这方便、快捷的管理这一切，而且大部分服务是免费的。

- 链接 https://www.dnspod.cn/

- FLask+ Python2.7

- 使用base64.b64encode 加密生成token，再调用dnspod API，查看解析log
